<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Shape</name>
    <message>
        <location filename="../Shape.js" line="+75"/>
        <source>Shape Tools</source>
        <translation>Formwerkzeuge</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show shape tools</source>
        <translation>Formwerkzeuge anzeigen</translation>
    </message>
    <message>
        <source>Show line tools</source>
        <translation type="vanished">Formwerkzeuge anzeigen</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Shape</source>
        <translation>&amp;Form</translation>
    </message>
    <message>
        <location filename="../Shape.ui" line="+17"/>
        <source>Create polyline</source>
        <translation>Polylinien konstruieren</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Fill</source>
        <translation>Füllung</translation>
    </message>
</context>
</TS>
